package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.mapper.SysAdsMapper;
import com.ruoyi.system.domain.SysAds;
import com.ruoyi.system.service.ISysAdsService;

/**
 * 首页广告Service业务层处理
 *
 * @author ruoyi
 * @date 2025-06-03
 */
@Service
public class SysAdsServiceImpl extends ServiceImpl<BaseMapper<SysAds>,SysAds> implements ISysAdsService
{
    @Autowired
    private SysAdsMapper sysAdsMapper;

    /**
     * 查询首页广告
     *
     * @param id 首页广告主键
     * @return 首页广告
     */
    @Override
    public SysAds selectSysAdsById(Long id)
    {
        return sysAdsMapper.selectSysAdsById(id);
    }

    /**
     * 查询首页广告列表
     *
     * @param sysAds 首页广告
     * @return 首页广告
     */
    @Override
    public List<SysAds> selectSysAdsList(SysAds sysAds)
    {
        return sysAdsMapper.selectSysAdsList(sysAds);
    }

    /**
     * 新增首页广告
     *
     * @param sysAds 首页广告
     * @return 结果
     */
    @Override
    public int insertSysAds(SysAds sysAds)
    {
        sysAds.setCreateTime(DateUtils.getNowDate());
        return sysAdsMapper.insertSysAds(sysAds);
    }

    /**
     * 修改首页广告
     *
     * @param sysAds 首页广告
     * @return 结果
     */
    @Override
    public int updateSysAds(SysAds sysAds)
    {
        sysAds.setUpdateTime(DateUtils.getNowDate());
        return sysAdsMapper.updateSysAds(sysAds);
    }

    /**
     * 批量删除首页广告
     *
     * @param ids 需要删除的首页广告主键
     * @return 结果
     */
    @Override
    public int deleteSysAdsByIds(Long[] ids)
    {
        return sysAdsMapper.deleteSysAdsByIds(ids);
    }

    /**
     * 删除首页广告信息
     *
     * @param id 首页广告主键
     * @return 结果
     */
    @Override
    public int deleteSysAdsById(Long id)
    {
        return sysAdsMapper.deleteSysAdsById(id);
    }
}
